# Taby

A pip package that highlights tabs

### Features
- Easy to use
- Fast
- Efficient

### Author
This pip package was created and maintained by Landon Hutchins

### Installation
The following are the steps on how to use the Taby package.

```sh
pip install taby
```


### Contributions
This project is currently closed to contributions

### License
MIT


